@@ -23,6 +23,7 @@ from .type_defs import (
     AcceptInboundConnectionResponseTypeDef,
     AdvancedSecurityOptionsInputTypeDef,
     AssociatePackageResponseTypeDef,
+    AuthorizeVpcEndpointAccessResponseTypeDef,
     AutoTuneOptionsInputTypeDef,
     AutoTuneOptionsTypeDef,
     CancelServiceSoftwareUpdateResponseTypeDef,
@@ -31,10 +32,12 @@ from .type_defs import (
     CreateDomainResponseTypeDef,
     CreateOutboundConnectionResponseTypeDef,
     CreatePackageResponseTypeDef,
+    CreateVpcEndpointResponseTypeDef,
     DeleteDomainResponseTypeDef,
     DeleteInboundConnectionResponseTypeDef,
     DeleteOutboundConnectionResponseTypeDef,
     DeletePackageResponseTypeDef,
+    DeleteVpcEndpointResponseTypeDef,
     DescribeDomainAutoTunesResponseTypeDef,
     DescribeDomainChangeProgressResponseTypeDef,
     DescribeDomainConfigResponseTypeDef,
@@ -47,6 +50,7 @@ from .type_defs import (
     DescribePackagesResponseTypeDef,
     DescribeReservedInstanceOfferingsResponseTypeDef,
     DescribeReservedInstancesResponseTypeDef,
+    DescribeVpcEndpointsResponseTypeDef,
     DissociatePackageResponseTypeDef,
     DomainEndpointOptionsTypeDef,
     DomainInformationContainerTypeDef,
@@ -64,6 +68,9 @@ from .type_defs import (
     ListPackagesForDomainResponseTypeDef,
     ListTagsResponseTypeDef,
     ListVersionsResponseTypeDef,
+    ListVpcEndpointAccessResponseTypeDef,
+    ListVpcEndpointsForDomainResponseTypeDef,
+    ListVpcEndpointsResponseTypeDef,
     LogPublishingOptionTypeDef,
     NodeToNodeEncryptionOptionsTypeDef,
     PackageSourceTypeDef,
@@ -74,6 +81,7 @@ from .type_defs import (
     TagTypeDef,
     UpdateDomainConfigResponseTypeDef,
     UpdatePackageResponseTypeDef,
+    UpdateVpcEndpointResponseTypeDef,
     UpgradeDomainResponseTypeDef,
     VPCOptionsTypeDef,
 )
@@ -131,8 +139,8 @@ class OpenSearchServiceClient(BaseClient):
         self, *, ConnectionId: str
     ) -> AcceptInboundConnectionResponseTypeDef:
         """
-        Allows the remote domain owner to accept an inbound cross-cluster connection
-        request.
+        Allows the destination Amazon OpenSearch Service domain owner to accept an
+        inbound cross-cluster search connection request.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.accept_inbound_connection)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#accept_inbound_connection)
@@ -140,7 +148,7 @@ class OpenSearchServiceClient(BaseClient):
 
     def add_tags(self, *, ARN: str, TagList: Sequence[TagTypeDef]) -> EmptyResponseMetadataTypeDef:
         """
-        Attaches tags to an existing domain.
+        Attaches tags to an existing Amazon OpenSearch Service domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.add_tags)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#add_tags)
@@ -156,6 +164,17 @@ class OpenSearchServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#associate_package)
         """
 
+    def authorize_vpc_endpoint_access(
+        self, *, DomainName: str, Account: str
+    ) -> AuthorizeVpcEndpointAccessResponseTypeDef:
+        """
+        Provides access to an Amazon OpenSearch Service domain through the use of an
+        interface VPC endpoint.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.authorize_vpc_endpoint_access)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#authorize_vpc_endpoint_access)
+        """
+
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
@@ -204,7 +223,7 @@ class OpenSearchServiceClient(BaseClient):
         AutoTuneOptions: AutoTuneOptionsInputTypeDef = ...
     ) -> CreateDomainResponseTypeDef:
         """
-        Creates a new Amazon OpenSearch Service domain.
+        Creates an Amazon OpenSearch Service domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.create_domain)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#create_domain)
@@ -218,8 +237,8 @@ class OpenSearchServiceClient(BaseClient):
         ConnectionAlias: str
     ) -> CreateOutboundConnectionResponseTypeDef:
         """
-        Creates a new cross-cluster connection from a local OpenSearch domain to a
-        remote OpenSearch domain.
+        Creates a new cross-cluster search connection from a source Amazon OpenSearch
+        Service domain to a destination domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.create_outbound_connection)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#create_outbound_connection)
@@ -234,15 +253,25 @@ class OpenSearchServiceClient(BaseClient):
         PackageDescription: str = ...
     ) -> CreatePackageResponseTypeDef:
         """
-        Create a package for use with Amazon OpenSearch Service domains.
+        Creates a package for use with Amazon OpenSearch Service domains.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.create_package)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#create_package)
         """
 
+    def create_vpc_endpoint(
+        self, *, DomainArn: str, VpcOptions: VPCOptionsTypeDef, ClientToken: str = ...
+    ) -> CreateVpcEndpointResponseTypeDef:
+        """
+        Creates an Amazon OpenSearch Service-managed VPC endpoint.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.create_vpc_endpoint)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#create_vpc_endpoint)
+        """
+
     def delete_domain(self, *, DomainName: str) -> DeleteDomainResponseTypeDef:
         """
-        Permanently deletes the specified domain and all of its data.
+        Deletes an Amazon OpenSearch Service domain and all of its data.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.delete_domain)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#delete_domain)
@@ -252,8 +281,8 @@ class OpenSearchServiceClient(BaseClient):
         self, *, ConnectionId: str
     ) -> DeleteInboundConnectionResponseTypeDef:
         """
-        Allows the remote domain owner to delete an existing inbound cross-cluster
-        connection.
+        Allows the destination Amazon OpenSearch Service domain owner to delete an
+        existing inbound cross-cluster search connection.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.delete_inbound_connection)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#delete_inbound_connection)
@@ -263,8 +292,8 @@ class OpenSearchServiceClient(BaseClient):
         self, *, ConnectionId: str
     ) -> DeleteOutboundConnectionResponseTypeDef:
         """
-        Allows the local domain owner to delete an existing outbound cross-cluster
-        connection.
+        Allows the source Amazon OpenSearch Service domain owner to delete an existing
+        outbound cross-cluster search connection.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.delete_outbound_connection)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#delete_outbound_connection)
@@ -272,16 +301,24 @@ class OpenSearchServiceClient(BaseClient):
 
     def delete_package(self, *, PackageID: str) -> DeletePackageResponseTypeDef:
         """
-        Deletes the package.
+        Deletes an Amazon OpenSearch Service package.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.delete_package)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#delete_package)
         """
 
+    def delete_vpc_endpoint(self, *, VpcEndpointId: str) -> DeleteVpcEndpointResponseTypeDef:
+        """
+        Deletes an Amazon OpenSearch Service-managed interface VPC endpoint.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.delete_vpc_endpoint)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#delete_vpc_endpoint)
+        """
+
     def describe_domain(self, *, DomainName: str) -> DescribeDomainResponseTypeDef:
         """
-        Returns domain configuration information about the specified domain, including
-        the domain ID, domain endpoint, and domain ARN.
+        Describes the domain configuration for the specified Amazon OpenSearch Service
+        domain, including the domain ID, domain service endpoint, and domain ARN.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.describe_domain)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#describe_domain)
@@ -291,8 +328,8 @@ class OpenSearchServiceClient(BaseClient):
         self, *, DomainName: str, MaxResults: int = ..., NextToken: str = ...
     ) -> DescribeDomainAutoTunesResponseTypeDef:
         """
-        Provides scheduled Auto-Tune action details for the domain, such as Auto-Tune
-        action type, description, severity, and scheduled date.
+        Returns the list of optimizations that Auto-Tune has made to an Amazon
+        OpenSearch Service domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.describe_domain_auto_tunes)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#describe_domain_auto_tunes)
@@ -302,8 +339,8 @@ class OpenSearchServiceClient(BaseClient):
         self, *, DomainName: str, ChangeId: str = ...
     ) -> DescribeDomainChangeProgressResponseTypeDef:
         """
-        Returns information about the current blue/green deployment happening on a
-        domain, including a change ID, status, and progress stages.
+        Returns information about the current blue/green deployment happening on an
+        Amazon OpenSearch Service domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.describe_domain_change_progress)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#describe_domain_change_progress)
@@ -311,8 +348,7 @@ class OpenSearchServiceClient(BaseClient):
 
     def describe_domain_config(self, *, DomainName: str) -> DescribeDomainConfigResponseTypeDef:
         """
-        Provides cluster configuration information about the specified domain, such as
-        the state, creation date, update version, and update date for cluster options.
+        Returns the configuration of an Amazon OpenSearch Service domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.describe_domain_config)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#describe_domain_config)
@@ -320,8 +356,8 @@ class OpenSearchServiceClient(BaseClient):
 
     def describe_domains(self, *, DomainNames: Sequence[str]) -> DescribeDomainsResponseTypeDef:
         """
-        Returns domain configuration information about the specified domains, including
-        the domain ID, domain endpoint, and domain ARN.
+        Returns domain configuration information about the specified Amazon OpenSearch
+        Service domains.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.describe_domains)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#describe_domains)
@@ -331,7 +367,8 @@ class OpenSearchServiceClient(BaseClient):
         self, *, Filters: Sequence[FilterTypeDef] = ..., MaxResults: int = ..., NextToken: str = ...
     ) -> DescribeInboundConnectionsResponseTypeDef:
         """
-        Lists all the inbound cross-cluster connections for a remote domain.
+        Lists all the inbound cross-cluster search connections for a destination
+        (remote) Amazon OpenSearch Service domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.describe_inbound_connections)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#describe_inbound_connections)
@@ -345,8 +382,8 @@ class OpenSearchServiceClient(BaseClient):
         DomainName: str = ...
     ) -> DescribeInstanceTypeLimitsResponseTypeDef:
         """
-        Describe the limits for a given instance type and OpenSearch or Elasticsearch
-        version.
+        Describes the instance count, storage, and master node limits for a given
+        OpenSearch or Elasticsearch version and instance type.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.describe_instance_type_limits)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#describe_instance_type_limits)
@@ -356,7 +393,8 @@ class OpenSearchServiceClient(BaseClient):
         self, *, Filters: Sequence[FilterTypeDef] = ..., MaxResults: int = ..., NextToken: str = ...
     ) -> DescribeOutboundConnectionsResponseTypeDef:
         """
-        Lists all the outbound cross-cluster connections for a local domain.
+        Lists all the outbound cross-cluster connections for a local (source) Amazon
+        OpenSearch Service domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.describe_outbound_connections)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#describe_outbound_connections)
@@ -370,7 +408,7 @@ class OpenSearchServiceClient(BaseClient):
         NextToken: str = ...
     ) -> DescribePackagesResponseTypeDef:
         """
-        Describes all packages available to Amazon OpenSearch Service domains.
+        Describes all packages available to OpenSearch Service.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.describe_packages)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#describe_packages)
@@ -380,7 +418,8 @@ class OpenSearchServiceClient(BaseClient):
         self, *, ReservedInstanceOfferingId: str = ..., MaxResults: int = ..., NextToken: str = ...
     ) -> DescribeReservedInstanceOfferingsResponseTypeDef:
         """
-        Lists available reserved OpenSearch instance offerings.
+        Describes the available Amazon OpenSearch Service Reserved Instance offerings
+        for a given Region.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.describe_reserved_instance_offerings)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#describe_reserved_instance_offerings)
@@ -390,17 +429,28 @@ class OpenSearchServiceClient(BaseClient):
         self, *, ReservedInstanceId: str = ..., MaxResults: int = ..., NextToken: str = ...
     ) -> DescribeReservedInstancesResponseTypeDef:
         """
-        Returns information about reserved OpenSearch instances for this account.
+        Describes the Amazon OpenSearch Service instances that you have reserved in a
+        given Region.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.describe_reserved_instances)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#describe_reserved_instances)
         """
 
+    def describe_vpc_endpoints(
+        self, *, VpcEndpointIds: Sequence[str]
+    ) -> DescribeVpcEndpointsResponseTypeDef:
+        """
+        Describes one or more Amazon OpenSearch Service-managed VPC endpoints.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.describe_vpc_endpoints)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#describe_vpc_endpoints)
+        """
+
     def dissociate_package(
         self, *, PackageID: str, DomainName: str
     ) -> DissociatePackageResponseTypeDef:
         """
-        Dissociates a package from the Amazon OpenSearch Service domain.
+        Removes a package from the specified Amazon OpenSearch Service domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.dissociate_package)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#dissociate_package)
@@ -424,7 +474,8 @@ class OpenSearchServiceClient(BaseClient):
         self, *, DomainName: str = ...
     ) -> GetCompatibleVersionsResponseTypeDef:
         """
-        Returns a list of upgrade-compatible versions of OpenSearch/Elasticsearch.
+        Returns a map of OpenSearch or Elasticsearch versions and the versions you can
+        upgrade them to.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.get_compatible_versions)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#get_compatible_versions)
@@ -434,8 +485,8 @@ class OpenSearchServiceClient(BaseClient):
         self, *, PackageID: str, MaxResults: int = ..., NextToken: str = ...
     ) -> GetPackageVersionHistoryResponseTypeDef:
         """
-        Returns a list of package versions, along with their creation time and commit
-        message.
+        Returns a list of Amazon OpenSearch Service package versions, along with their
+        creation time and commit message.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.get_package_version_history)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#get_package_version_history)
@@ -445,7 +496,8 @@ class OpenSearchServiceClient(BaseClient):
         self, *, DomainName: str, MaxResults: int = ..., NextToken: str = ...
     ) -> GetUpgradeHistoryResponseTypeDef:
         """
-        Retrieves the complete history of the last 10 upgrades performed on the domain.
+        Retrieves the complete history of the last 10 upgrades performed on an Amazon
+        OpenSearch Service domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.get_upgrade_history)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#get_upgrade_history)
@@ -453,8 +505,8 @@ class OpenSearchServiceClient(BaseClient):
 
     def get_upgrade_status(self, *, DomainName: str) -> GetUpgradeStatusResponseTypeDef:
         """
-        Retrieves the latest status of the last upgrade or upgrade eligibility check
-        performed on the domain.
+        Returns the most recent status of the last upgrade or upgrade eligibility check
+        performed on an Amazon OpenSearch Service domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.get_upgrade_status)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#get_upgrade_status)
@@ -464,7 +516,8 @@ class OpenSearchServiceClient(BaseClient):
         self, *, EngineType: EngineTypeType = ...
     ) -> ListDomainNamesResponseTypeDef:
         """
-        Returns the names of all domains owned by the current user's account.
+        Returns the names of all Amazon OpenSearch Service domains owned by the current
+        user in the active Region.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.list_domain_names)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#list_domain_names)
@@ -474,7 +527,7 @@ class OpenSearchServiceClient(BaseClient):
         self, *, PackageID: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListDomainsForPackageResponseTypeDef:
         """
-        Lists all Amazon OpenSearch Service domains associated with the package.
+        Lists all Amazon OpenSearch Service domains associated with a given package.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.list_domains_for_package)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#list_domains_for_package)
@@ -489,8 +542,8 @@ class OpenSearchServiceClient(BaseClient):
         NextToken: str = ...
     ) -> ListInstanceTypeDetailsResponseTypeDef:
         """
-        See also: [AWS API
-        Documentation](https://docs.aws.amazon.com/goto/WebAPI/opensearch-2021-01-01/ListInstanceTypeDetails).
+        Lists all instance types and available features for a given OpenSearch or
+        Elasticsearch version.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.list_instance_type_details)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#list_instance_type_details)
@@ -500,7 +553,7 @@ class OpenSearchServiceClient(BaseClient):
         self, *, DomainName: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListPackagesForDomainResponseTypeDef:
         """
-        Lists all packages associated with the Amazon OpenSearch Service domain.
+        Lists all packages associated with an Amazon OpenSearch Service domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.list_packages_for_domain)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#list_packages_for_domain)
@@ -508,7 +561,7 @@ class OpenSearchServiceClient(BaseClient):
 
     def list_tags(self, *, ARN: str) -> ListTagsResponseTypeDef:
         """
-        Returns all tags for the given domain.
+        Returns all resource tags for an Amazon OpenSearch Service domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.list_tags)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#list_tags)
@@ -518,17 +571,50 @@ class OpenSearchServiceClient(BaseClient):
         self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListVersionsResponseTypeDef:
         """
-        List all supported versions of OpenSearch and Elasticsearch.
+        Lists all versions of OpenSearch and Elasticsearch that Amazon OpenSearch
+        Service supports.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.list_versions)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#list_versions)
         """
 
+    def list_vpc_endpoint_access(
+        self, *, DomainName: str, NextToken: str = ...
+    ) -> ListVpcEndpointAccessResponseTypeDef:
+        """
+        Retrieves information about each Amazon Web Services principal that is allowed
+        to access a given Amazon OpenSearch Service domain through the use of an
+        interface VPC endpoint.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.list_vpc_endpoint_access)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#list_vpc_endpoint_access)
+        """
+
+    def list_vpc_endpoints(self, *, NextToken: str = ...) -> ListVpcEndpointsResponseTypeDef:
+        """
+        Retrieves all Amazon OpenSearch Service-managed VPC endpoints in the current
+        Amazon Web Services account and Region.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.list_vpc_endpoints)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#list_vpc_endpoints)
+        """
+
+    def list_vpc_endpoints_for_domain(
+        self, *, DomainName: str, NextToken: str = ...
+    ) -> ListVpcEndpointsForDomainResponseTypeDef:
+        """
+        Retrieves all Amazon OpenSearch Service-managed VPC endpoints associated with a
+        particular domain.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.list_vpc_endpoints_for_domain)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#list_vpc_endpoints_for_domain)
+        """
+
     def purchase_reserved_instance_offering(
         self, *, ReservedInstanceOfferingId: str, ReservationName: str, InstanceCount: int = ...
     ) -> PurchaseReservedInstanceOfferingResponseTypeDef:
         """
-        Allows you to purchase reserved OpenSearch instances.
+        Allows you to purchase Amazon OpenSearch Service Reserved Instances.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.purchase_reserved_instance_offering)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#purchase_reserved_instance_offering)
@@ -538,8 +624,8 @@ class OpenSearchServiceClient(BaseClient):
         self, *, ConnectionId: str
     ) -> RejectInboundConnectionResponseTypeDef:
         """
-        Allows the remote domain owner to reject an inbound cross-cluster connection
-        request.
+        Allows the remote Amazon OpenSearch Service domain owner to reject an inbound
+        cross-cluster connection request.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.reject_inbound_connection)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#reject_inbound_connection)
@@ -547,12 +633,21 @@ class OpenSearchServiceClient(BaseClient):
 
     def remove_tags(self, *, ARN: str, TagKeys: Sequence[str]) -> EmptyResponseMetadataTypeDef:
         """
-        Removes the specified set of tags from the given domain.
+        Removes the specified set of tags from an Amazon OpenSearch Service domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.remove_tags)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#remove_tags)
         """
 
+    def revoke_vpc_endpoint_access(self, *, DomainName: str, Account: str) -> Dict[str, Any]:
+        """
+        Revokes access to an Amazon OpenSearch Service domain that was provided through
+        an interface VPC endpoint.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.revoke_vpc_endpoint_access)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#revoke_vpc_endpoint_access)
+        """
+
     def start_service_software_update(
         self, *, DomainName: str
     ) -> StartServiceSoftwareUpdateResponseTypeDef:
@@ -583,8 +678,8 @@ class OpenSearchServiceClient(BaseClient):
         DryRun: bool = ...
     ) -> UpdateDomainConfigResponseTypeDef:
         """
-        Modifies the cluster configuration of the specified domain, such as setting the
-        instance type and the number of instances.
+        Modifies the cluster configuration of the specified Amazon OpenSearch Service
+        domain.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.update_domain_config)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#update_domain_config)
@@ -605,6 +700,16 @@ class OpenSearchServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#update_package)
         """
 
+    def update_vpc_endpoint(
+        self, *, VpcEndpointId: str, VpcOptions: VPCOptionsTypeDef
+    ) -> UpdateVpcEndpointResponseTypeDef:
+        """
+        Modifies an Amazon OpenSearch Service-managed interface VPC endpoint.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.update_vpc_endpoint)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#update_vpc_endpoint)
+        """
+
     def upgrade_domain(
         self,
         *,
@@ -614,8 +719,9 @@ class OpenSearchServiceClient(BaseClient):
         AdvancedOptions: Mapping[str, str] = ...
     ) -> UpgradeDomainResponseTypeDef:
         """
-        Allows you to either upgrade your domain or perform an upgrade eligibility check
-        to a compatible version of OpenSearch or Elasticsearch.
+        Allows you to either upgrade your Amazon OpenSearch Service domain or perform an
+        upgrade eligibility check to a compatible version of OpenSearch or
+        Elasticsearch.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearch.html#OpenSearchService.Client.upgrade_domain)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#upgrade_domain)
