@@ -36,6 +36,7 @@ __all__ = (
     "OverallChangeStatusType",
     "PackageStatusType",
     "PackageTypeType",
+    "PrincipalTypeType",
     "ReservedInstancePaymentOptionType",
     "RollbackOnDisableType",
     "ScheduledAutoTuneActionTypeType",
@@ -45,6 +46,8 @@ __all__ = (
     "UpgradeStatusType",
     "UpgradeStepType",
     "VolumeTypeType",
+    "VpcEndpointErrorCodeType",
+    "VpcEndpointStatusType",
     "OpenSearchServiceServiceName",
     "ServiceName",
     "ResourceServiceName",
@@ -209,6 +212,7 @@ PackageStatusType = Literal[
     "VALIDATION_FAILED",
 ]
 PackageTypeType = Literal["TXT-DICTIONARY"]
+PrincipalTypeType = Literal["AWS_ACCOUNT", "AWS_SERVICE"]
 ReservedInstancePaymentOptionType = Literal["ALL_UPFRONT", "NO_UPFRONT", "PARTIAL_UPFRONT"]
 RollbackOnDisableType = Literal["DEFAULT_ROLLBACK", "NO_ROLLBACK"]
 ScheduledAutoTuneActionTypeType = Literal["JVM_HEAP_SIZE_TUNING", "JVM_YOUNG_GEN_TUNING"]
@@ -218,6 +222,10 @@ TimeUnitType = Literal["HOURS"]
 UpgradeStatusType = Literal["FAILED", "IN_PROGRESS", "SUCCEEDED", "SUCCEEDED_WITH_ISSUES"]
 UpgradeStepType = Literal["PRE_UPGRADE_CHECK", "SNAPSHOT", "UPGRADE"]
 VolumeTypeType = Literal["gp2", "gp3", "io1", "standard"]
+VpcEndpointErrorCodeType = Literal["ENDPOINT_NOT_FOUND", "SERVER_ERROR"]
+VpcEndpointStatusType = Literal[
+    "ACTIVE", "CREATE_FAILED", "CREATING", "DELETE_FAILED", "DELETING", "UPDATE_FAILED", "UPDATING"
+]
 OpenSearchServiceServiceName = Literal["opensearch"]
 ServiceName = Literal[
     "accessanalyzer",
@@ -467,6 +475,7 @@ ServiceName = Literal[
     "redshift-serverless",
     "rekognition",
     "resiliencehub",
+    "resource-explorer-2",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
