@@ -30,6 +30,7 @@ from .literals import (
     OutboundConnectionStatusCodeType,
     OverallChangeStatusType,
     PackageStatusType,
+    PrincipalTypeType,
     ReservedInstancePaymentOptionType,
     RollbackOnDisableType,
     ScheduledAutoTuneActionTypeType,
@@ -38,6 +39,8 @@ from .literals import (
     UpgradeStatusType,
     UpgradeStepType,
     VolumeTypeType,
+    VpcEndpointErrorCodeType,
+    VpcEndpointStatusType,
 )
 
 if sys.version_info >= (3, 9):
@@ -59,6 +62,8 @@ __all__ = (
     "AdditionalLimitTypeDef",
     "MasterUserOptionsTypeDef",
     "AssociatePackageRequestRequestTypeDef",
+    "AuthorizeVpcEndpointAccessRequestRequestTypeDef",
+    "AuthorizedPrincipalTypeDef",
     "ScheduledAutoTuneDetailsTypeDef",
     "DurationTypeDef",
     "AutoTuneOptionsOutputTypeDef",
@@ -84,6 +89,8 @@ __all__ = (
     "DeleteInboundConnectionRequestRequestTypeDef",
     "DeleteOutboundConnectionRequestRequestTypeDef",
     "DeletePackageRequestRequestTypeDef",
+    "DeleteVpcEndpointRequestRequestTypeDef",
+    "VpcEndpointSummaryTypeDef",
     "DescribeDomainAutoTunesRequestRequestTypeDef",
     "DescribeDomainChangeProgressRequestRequestTypeDef",
     "DescribeDomainConfigRequestRequestTypeDef",
@@ -94,6 +101,8 @@ __all__ = (
     "DescribePackagesFilterTypeDef",
     "DescribeReservedInstanceOfferingsRequestRequestTypeDef",
     "DescribeReservedInstancesRequestRequestTypeDef",
+    "DescribeVpcEndpointsRequestRequestTypeDef",
+    "VpcEndpointErrorTypeDef",
     "DissociatePackageRequestRequestTypeDef",
     "DomainInfoTypeDef",
     "ErrorDetailsTypeDef",
@@ -113,10 +122,14 @@ __all__ = (
     "ListPackagesForDomainRequestRequestTypeDef",
     "ListTagsRequestRequestTypeDef",
     "ListVersionsRequestRequestTypeDef",
+    "ListVpcEndpointAccessRequestRequestTypeDef",
+    "ListVpcEndpointsForDomainRequestRequestTypeDef",
+    "ListVpcEndpointsRequestRequestTypeDef",
     "PurchaseReservedInstanceOfferingRequestRequestTypeDef",
     "RecurringChargeTypeDef",
     "RejectInboundConnectionRequestRequestTypeDef",
     "RemoveTagsRequestRequestTypeDef",
+    "RevokeVpcEndpointAccessRequestRequestTypeDef",
     "SAMLIdpTypeDef",
     "StartServiceSoftwareUpdateRequestRequestTypeDef",
     "StorageTypeLimitTypeDef",
@@ -132,6 +145,8 @@ __all__ = (
     "VersionStatusTypeDef",
     "AddTagsRequestRequestTypeDef",
     "ListTagsResponseTypeDef",
+    "AuthorizeVpcEndpointAccessResponseTypeDef",
+    "ListVpcEndpointAccessResponseTypeDef",
     "AutoTuneDetailsTypeDef",
     "AutoTuneMaintenanceScheduleTypeDef",
     "CancelServiceSoftwareUpdateResponseTypeDef",
@@ -147,8 +162,13 @@ __all__ = (
     "LogPublishingOptionsStatusTypeDef",
     "NodeToNodeEncryptionOptionsStatusTypeDef",
     "SnapshotOptionsStatusTypeDef",
+    "CreateVpcEndpointRequestRequestTypeDef",
+    "UpdateVpcEndpointRequestRequestTypeDef",
     "CreatePackageRequestRequestTypeDef",
     "UpdatePackageRequestRequestTypeDef",
+    "DeleteVpcEndpointResponseTypeDef",
+    "ListVpcEndpointsForDomainResponseTypeDef",
+    "ListVpcEndpointsResponseTypeDef",
     "DescribeInboundConnectionsRequestRequestTypeDef",
     "DescribeOutboundConnectionsRequestRequestTypeDef",
     "DescribePackagesRequestRequestTypeDef",
@@ -156,6 +176,7 @@ __all__ = (
     "DomainPackageDetailsTypeDef",
     "PackageDetailsTypeDef",
     "VPCDerivedInfoStatusTypeDef",
+    "VpcEndpointTypeDef",
     "GetPackageVersionHistoryResponseTypeDef",
     "InstanceLimitsTypeDef",
     "ListInstanceTypeDetailsResponseTypeDef",
@@ -182,6 +203,9 @@ __all__ = (
     "DeletePackageResponseTypeDef",
     "DescribePackagesResponseTypeDef",
     "UpdatePackageResponseTypeDef",
+    "CreateVpcEndpointResponseTypeDef",
+    "DescribeVpcEndpointsResponseTypeDef",
+    "UpdateVpcEndpointResponseTypeDef",
     "DescribeReservedInstanceOfferingsResponseTypeDef",
     "DescribeReservedInstancesResponseTypeDef",
     "AdvancedSecurityOptionsInputTypeDef",
@@ -307,6 +331,23 @@ AssociatePackageRequestRequestTypeDef = TypedDict(
     },
 )
 
+AuthorizeVpcEndpointAccessRequestRequestTypeDef = TypedDict(
+    "AuthorizeVpcEndpointAccessRequestRequestTypeDef",
+    {
+        "DomainName": str,
+        "Account": str,
+    },
+)
+
+AuthorizedPrincipalTypeDef = TypedDict(
+    "AuthorizedPrincipalTypeDef",
+    {
+        "PrincipalType": PrincipalTypeType,
+        "Principal": str,
+    },
+    total=False,
+)
+
 ScheduledAutoTuneDetailsTypeDef = TypedDict(
     "ScheduledAutoTuneDetailsTypeDef",
     {
@@ -549,6 +590,24 @@ DeletePackageRequestRequestTypeDef = TypedDict(
     },
 )
 
+DeleteVpcEndpointRequestRequestTypeDef = TypedDict(
+    "DeleteVpcEndpointRequestRequestTypeDef",
+    {
+        "VpcEndpointId": str,
+    },
+)
+
+VpcEndpointSummaryTypeDef = TypedDict(
+    "VpcEndpointSummaryTypeDef",
+    {
+        "VpcEndpointId": str,
+        "VpcEndpointOwner": str,
+        "DomainArn": str,
+        "Status": VpcEndpointStatusType,
+    },
+    total=False,
+)
+
 _RequiredDescribeDomainAutoTunesRequestRequestTypeDef = TypedDict(
     "_RequiredDescribeDomainAutoTunesRequestRequestTypeDef",
     {
@@ -676,6 +735,23 @@ DescribeReservedInstancesRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
+DescribeVpcEndpointsRequestRequestTypeDef = TypedDict(
+    "DescribeVpcEndpointsRequestRequestTypeDef",
+    {
+        "VpcEndpointIds": Sequence[str],
+    },
+)
+
+VpcEndpointErrorTypeDef = TypedDict(
+    "VpcEndpointErrorTypeDef",
+    {
+        "VpcEndpointId": str,
+        "ErrorCode": VpcEndpointErrorCodeType,
+        "ErrorMessage": str,
+    },
+    total=False,
+)
+
 DissociatePackageRequestRequestTypeDef = TypedDict(
     "DissociatePackageRequestRequestTypeDef",
     {
@@ -918,6 +994,58 @@ ListVersionsRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredListVpcEndpointAccessRequestRequestTypeDef = TypedDict(
+    "_RequiredListVpcEndpointAccessRequestRequestTypeDef",
+    {
+        "DomainName": str,
+    },
+)
+_OptionalListVpcEndpointAccessRequestRequestTypeDef = TypedDict(
+    "_OptionalListVpcEndpointAccessRequestRequestTypeDef",
+    {
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListVpcEndpointAccessRequestRequestTypeDef(
+    _RequiredListVpcEndpointAccessRequestRequestTypeDef,
+    _OptionalListVpcEndpointAccessRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredListVpcEndpointsForDomainRequestRequestTypeDef = TypedDict(
+    "_RequiredListVpcEndpointsForDomainRequestRequestTypeDef",
+    {
+        "DomainName": str,
+    },
+)
+_OptionalListVpcEndpointsForDomainRequestRequestTypeDef = TypedDict(
+    "_OptionalListVpcEndpointsForDomainRequestRequestTypeDef",
+    {
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListVpcEndpointsForDomainRequestRequestTypeDef(
+    _RequiredListVpcEndpointsForDomainRequestRequestTypeDef,
+    _OptionalListVpcEndpointsForDomainRequestRequestTypeDef,
+):
+    pass
+
+
+ListVpcEndpointsRequestRequestTypeDef = TypedDict(
+    "ListVpcEndpointsRequestRequestTypeDef",
+    {
+        "NextToken": str,
+    },
+    total=False,
+)
+
 _RequiredPurchaseReservedInstanceOfferingRequestRequestTypeDef = TypedDict(
     "_RequiredPurchaseReservedInstanceOfferingRequestRequestTypeDef",
     {
@@ -965,6 +1093,14 @@ RemoveTagsRequestRequestTypeDef = TypedDict(
     },
 )
 
+RevokeVpcEndpointAccessRequestRequestTypeDef = TypedDict(
+    "RevokeVpcEndpointAccessRequestRequestTypeDef",
+    {
+        "DomainName": str,
+        "Account": str,
+    },
+)
+
 SAMLIdpTypeDef = TypedDict(
     "SAMLIdpTypeDef",
     {
@@ -1106,6 +1242,23 @@ ListTagsResponseTypeDef = TypedDict(
     },
 )
 
+AuthorizeVpcEndpointAccessResponseTypeDef = TypedDict(
+    "AuthorizeVpcEndpointAccessResponseTypeDef",
+    {
+        "AuthorizedPrincipal": AuthorizedPrincipalTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListVpcEndpointAccessResponseTypeDef = TypedDict(
+    "ListVpcEndpointAccessResponseTypeDef",
+    {
+        "AuthorizedPrincipalList": List[AuthorizedPrincipalTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 AutoTuneDetailsTypeDef = TypedDict(
     "AutoTuneDetailsTypeDef",
     {
@@ -1250,6 +1403,36 @@ SnapshotOptionsStatusTypeDef = TypedDict(
     },
 )
 
+_RequiredCreateVpcEndpointRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateVpcEndpointRequestRequestTypeDef",
+    {
+        "DomainArn": str,
+        "VpcOptions": VPCOptionsTypeDef,
+    },
+)
+_OptionalCreateVpcEndpointRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateVpcEndpointRequestRequestTypeDef",
+    {
+        "ClientToken": str,
+    },
+    total=False,
+)
+
+
+class CreateVpcEndpointRequestRequestTypeDef(
+    _RequiredCreateVpcEndpointRequestRequestTypeDef, _OptionalCreateVpcEndpointRequestRequestTypeDef
+):
+    pass
+
+
+UpdateVpcEndpointRequestRequestTypeDef = TypedDict(
+    "UpdateVpcEndpointRequestRequestTypeDef",
+    {
+        "VpcEndpointId": str,
+        "VpcOptions": VPCOptionsTypeDef,
+    },
+)
+
 _RequiredCreatePackageRequestRequestTypeDef = TypedDict(
     "_RequiredCreatePackageRequestRequestTypeDef",
     {
@@ -1296,6 +1479,32 @@ class UpdatePackageRequestRequestTypeDef(
     pass
 
 
+DeleteVpcEndpointResponseTypeDef = TypedDict(
+    "DeleteVpcEndpointResponseTypeDef",
+    {
+        "VpcEndpointSummary": VpcEndpointSummaryTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListVpcEndpointsForDomainResponseTypeDef = TypedDict(
+    "ListVpcEndpointsForDomainResponseTypeDef",
+    {
+        "VpcEndpointSummaryList": List[VpcEndpointSummaryTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListVpcEndpointsResponseTypeDef = TypedDict(
+    "ListVpcEndpointsResponseTypeDef",
+    {
+        "VpcEndpointSummaryList": List[VpcEndpointSummaryTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 DescribeInboundConnectionsRequestRequestTypeDef = TypedDict(
     "DescribeInboundConnectionsRequestRequestTypeDef",
     {
@@ -1374,6 +1583,19 @@ VPCDerivedInfoStatusTypeDef = TypedDict(
     },
 )
 
+VpcEndpointTypeDef = TypedDict(
+    "VpcEndpointTypeDef",
+    {
+        "VpcEndpointId": str,
+        "VpcEndpointOwner": str,
+        "DomainArn": str,
+        "VpcOptions": VPCDerivedInfoTypeDef,
+        "Status": VpcEndpointStatusType,
+        "Endpoint": str,
+    },
+    total=False,
+)
+
 GetPackageVersionHistoryResponseTypeDef = TypedDict(
     "GetPackageVersionHistoryResponseTypeDef",
     {
@@ -1639,6 +1861,31 @@ UpdatePackageResponseTypeDef = TypedDict(
     },
 )
 
+CreateVpcEndpointResponseTypeDef = TypedDict(
+    "CreateVpcEndpointResponseTypeDef",
+    {
+        "VpcEndpoint": VpcEndpointTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeVpcEndpointsResponseTypeDef = TypedDict(
+    "DescribeVpcEndpointsResponseTypeDef",
+    {
+        "VpcEndpoints": List[VpcEndpointTypeDef],
+        "VpcEndpointErrors": List[VpcEndpointErrorTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdateVpcEndpointResponseTypeDef = TypedDict(
+    "UpdateVpcEndpointResponseTypeDef",
+    {
+        "VpcEndpoint": VpcEndpointTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 DescribeReservedInstanceOfferingsResponseTypeDef = TypedDict(
     "DescribeReservedInstanceOfferingsResponseTypeDef",
     {
